setSatelliteDir. See getDaylightHours() for details
regarding how daylight hours are calculated.goesaodc_downloadDaytimeAOD.RdDownload GOES-16 or GOES-17 AOD data for the daylight hours of a specific date and location.
#' @description Download all daylight files available to directory specified
with setSatelliteDir. See getDaylightHours() for details
regarding how daylight hours are calculated.
goesaodc_downloadDaytimeAOD( satID = NULL, datetime = NULL, longitude = NULL, latitude = NULL, bbox = NULL, timezone = NULL, isJulian = FALSE, verbose = FALSE )
| satID | ID of the source GOES satellite (G16 or G17). |
|---|---|
| datetime | Specific date for which daylight hours are requested. |
| longitude | Longitude of the location of interest in decimal degrees E. |
| latitude | Latitude of the location of interest in decimal degrees N. |
| bbox | Bounding box for the region of interest, Default: CONUS. |
| timezone | Timezone in which to interpret the |
| isJulian | Logical value determining whether datetime should be interpreted as a Julian date with day of year as a decimal number. |
| verbose | Logical specifies whether to show status of file download. |
Invisibly returns a vector of local files matching the requested datetime.
# \donttest{ # List locally available files for a specific date by timezone library(MazamaSatelliteUtils) library(MazamaSpatialUtils) setSatelliteDataDir("~/Data/Satellite") setSpatialDataDir("~/Data/Spatial") goesaodc_downloadDaytimeAOD( satID = "G16", datetime = "2019-09-06", timezone = "America/Los_Angeles") # }